@@ -1,3 +1,3 @@
 # frozen_string_literal: true
 
-require 'dry/core'
+require "dry/core"
